@@ -63,7 +63,7 @@ def convertpot(inputpotfile, outputpofile, templatepofile, tm=None, min_similari
     try:
       fuzzyfilematcher = match.matcher(templatepo, max_candidates=1, min_similarity=75, max_length=1000)
       fuzzyfilematcher.addpercentage = False
-    except:
+    except ValueError:
       fuzzyfilematcher = None
     templatepo.makeindex()
     templateheadervalues = templatepo.parseheader()
@@ -88,15 +88,17 @@ def convertpot(inputpotfile, outputpofile, templatepofile, tm=None, min_similari
       else:
         kwargs[key] = value
   try:
-    fuzzyglobalmatcher = memory(tmfiles, max_candidates=1, min_similarity=75, max_length=1000)
+    fuzzyglobalmatcher = memory(tm, max_candidates=1, min_similarity=75, max_length=1000)
     fuzzyglobalmatcher.addpercentage = False
-  except:
+  except ValueError:
     fuzzyglobalmatcher = None
   inputheadervalues = inputpot.parseheader()
   for key, value in inputheadervalues.iteritems():
-    if key in ("Project-Id-Version", "Last-Translator", "Language-Team", "PO-Revision-Date", "Content-Type", "Content-Transfer-Encoding", "Plural-Forms"):
+    if key in ("Last-Translator", "Language-Team", "PO-Revision-Date", "Content-Type", "Content-Transfer-Encoding", "Plural-Forms"):
       # want to carry these from the template so we ignore them
       pass
+    elif key == "Project-Id-Version":
+      project_id_version = value
     elif key == "POT-Creation-Date":
       pot_creation_date = value
     elif key == "MIME-Version":
@@ -132,7 +134,8 @@ def convertpot(inputpotfile, outputpofile, templatepofile, tm=None, min_similari
           if inputpotunit.source == templatepounit.source and templatepounit.target:
             inputpotunit.merge(templatepounit)
             break
-        else: 
+        else:
+          fuzzycandidates = []
           if fuzzyfilematcher:
             fuzzycandidates = fuzzyfilematcher.matches(inputpotunit.source)
             if fuzzycandidates:
